# **_sports_**

_Article_

## **Monitoring Athletes during Training Camps:** **Observations and Translatable Strategies from** **Elite Road Cyclists and Swimmers**

**Anna E. Saw** **\[1,\]** \*\*\*\*\* **[\[ID\]](https://orcid.org/0000-0002-4461-2469)** **, Shona L. Halson** **\[2\]** **and Iñigo Mujika** **[\[3,4\]\[ ID\]](https://orcid.org/0000-0002-8143-9132)**

1 Cricket Australia, 60 Jolimont St, Jolimont, VIC 3002, Australia
2 AIS Physiology, Australian Institute of Sport, Leverrier St, Bruce, ACT 2617, Australia;
<shona.halson@gmail.com>
3 Department of Physiology, Faculty of Medicine and Odontology, University of the Basque Country,
48940 Leioa, Basque Country, Spain; <inigo.mujika@inigomujika.com>
4 Exercise Science Laboratory, School of Kinesiology, Faculty of Medicine, Universidad Finis Terrae,
Santiago 1509, Chile
\*\*\*\*\* Correspondence: <anna.saw@cricket.com.au>

Received: 17 June 2018; Accepted: 11 July 2018; Published: 20 July 2018

���������
**[�������](http://www.mdpi.com/2075-4663/6/3/63?type=check_update&version=2)**

**Abstract:** Monitoring is an essential yet unstandardized component of managing athletic preparation.
The purpose of this paper is to provide insight into the typical measurements and responses
observed from monitoring elite road cyclist and swimmers during training camps, and translate these
observations to practical strategies for other practitioners to employ. Twenty-nine male professional
cyclists, 12 male and 19 female international swimmers participated in up to three of the eight
4–19 day training camps, held early in the season or leading into major competitions, at sea-level or
moderate altitude. Monitoring included body mass and composition, subjective sleep, urinary specific
gravity (USG), resting heart rate (HR) and peripheral oxygen saturation (SpO2) at altitude. Sum of
seven skinfolds most likely decreased in the order of 3.1 _±_ 3.6 mm week-to-week, accompanied by
a most likely trivial decrease in body mass of 0.4 _±_ 0.4 kg week-to-week. At altitude, sleep quality
very likely trivially improved week-to-week (0.3 _±_ 0.3 AU), SpO2 possibly increased week-to-week
(0.6 _±_ 1.7%), whilst changes in resting HR were unclear (0 _±_ 4 bpm). Sleep duration and USG were
stable. Comparing individual to group day-to-day change in monitored variables may prove effective
to flag athletes potentially at risk of training maladaptation. Practitioners may replicate these methods
to establish thresholds specific to their cohort and setting. This study provides further support for
a multi-faceted approach to monitoring elite athletes in training camp environments.

**Keywords:** altitude; body composition; sleep; heart rate; hydration

**1. Introduction**

Elite athletic preparation requires a fine balance between pushing the training and adaptation
boundaries for performance, and avoiding negative outcomes such as underperformance, injury,
or poor wellbeing \[1,2\]. Monitoring is therefore considered an essential component of managing
athletic preparation \[3\]. Monitoring efforts may be directed towards: (a) Ensuring athletes are healthy
and therefore receptive to positive training adaptations; (b) quantifying the physiological stress
experienced; and (c) assessing the physiological and psychological response to training \[1–3\]. Despite
growing research in this space, much of the data on elite athletes remains unpublished, thus hindering
advancement in the field \[3\].
Elite athletes often participate in training camps to enhance training adaptation at specific times
in the season. The nature of training camps is manipulated to align with certain goals, for instance

_Sports_ **2018**, _6_ [, 63; doi:10.3390/sports6030063](http://dx.doi.org/10.3390/sports6030063) [www.mdpi.com/journal/sports](http://www.mdpi.com/journal/sports)

_Sports_ **2018**, _6_, 63 2 of 9

improving aerobic or anaerobic capacities, preparing for a specific competition, and team cohesion.
Training camps pose additional, often intentional, challenges to the athlete state. For instance,
overreaching has been shown to be elicited with seven days of intensified training in trained cyclists \[4\],
yet may be detectable after only three days with daily monitoring \[5\]. Training at altitude adds
an additional dimension of complexity, with individual responses to the environmental stress of
hypoxia contributing to the training response \[6\]. The brief (i.e., several days to several weeks)
and semi-controlled structure of training camps presents an ideal setting to intensify monitoring
efforts to both manage adaptation and better understand how athletes respond to training \[7\].
Given the complexity of athletic preparation, several physical, physiological, and psychosocial
measures are typically employed to help monitor and manage elite athletes \[4,5,8\]. The utility of
each measure is dependent upon its ability to discern between what is normal fluctuation in a measure,
and what is a meaningful change requiring action. Therefore, it is important to understand how such
measures typically respond in different training camp scenarios, and what thresholds may be most
applicable. This is particularly important in elite athlete cohorts where very small changes can impact
performance \[9\]. As such, there is value in reporting ‘real world’ monitoring data from elite athletes to
assist practitioners working with similar cohorts and settings in the future. This could improve the
use of monitoring methods by providing evidence for what constitutes a ‘normal’ response, and what
thresholds may be applied to detect meaningful change.
The purpose of this study is firstly to describe the typical measurements and responses observed
from monitoring elite road cyclists and swimmers during eight training camps. Camps occurred
at different times of the season, and at sea-level and moderate altitude. A secondary purpose is
to translate these observations to practical strategies for practitioners seeking to effectively utilize
monitoring strategies with elite athletes in training camp settings.

**2. Materials and Methods**

_2.1. Subjects and Training Camps_

2.1.1. Cyclists

Twenty-nine male cyclists (age 29 _±_ 4 years) participated in one (n = 17), two (n = 9), or three
(n = 3) of the four team training camps held across a season. All cyclists were members of a UCI World
Tour cycling team. The sample included an Olympic Champion and Grand Tour (Giro d’Italia, Tour de
France, Vuelta a España) general classification podium finisher, and six Grand Tour stage winners.
Based on the team manager’s description and according to their main role in competition, 12 cyclists
were all terrain riders, 10 climbers, 5 sprinters, 1 flat terrain rider and 1 time trial specialist \[10\].
Four 9–12-day team training camps were conducted during the 2013 season: (i) pre-Tour Down
Under (TDU) at sea-level (December 2012); (ii) early-season at sea-level (January 2013); (iii) pre-Volta
a Catalunya (Volta) at sea-level (March 2013); and (iv) pre-Tour de France (TDF) at 2320 m altitude
(May 2013). The main purpose of the early season camp was to set fitness foundations for the riders
and work on team cohesion, whereas the other camps targeted specific competitive fitness for riders
who would take part in each particular race.

2.1.2. Swimmers

Thirty-one swimmers (19 female, age 21 _±_ 4 years; 12 male, age 23 _±_ 4 years) participated in one
(n = 22) or two (n = 9) of the four team training camps held between 2012 and 2016. All swimmers
were members of the French and Spanish pool or open water national teams, and participated in major
international competitions. The sample included two Olympic champions, seven world champions,
and three world record holders.

Four 4–19-day team training camps were conducted during the 2012–2016 seasons: (i) Early-season
at 1360 m altitude (January 2012); (ii) pre-London Olympic Games at sea-level (July 2012); (iii) pre-Kazan

_Sports_ **2018**, _6_, 63 3 of 9

World Championships at 2320 m altitude (June 2015); and (iv) pre-Rio Olympic Games at 2320 m altitude
(May 2016). The main purpose of the early season camp was to set fitness foundations for the swimmers
through moderate altitude after a brief 3–7 day end-of-year break, whereas the other camps targeted
specific competitive fitness for swimmers who would take part in each particular competition.

_2.2. Methods_

Procedures formed part of the teams’ service provision, which conforms to the Code of Ethics
of the World Medical Association (Declaration of Helsinki). Athletes provided informed consent to
participate in monitoring procedures associated with team duties, with the understanding that data
may be used for research purposes.
Urinary specific gravity (USG, UG-α Digital Refractometer, Atago Co., Tokyo, Japan) was
monitored daily on waking, in a mid-stream urine sample. Body mass (Seca 877, Hamburg, Germany)
was then monitored after voiding. Skinfolds were measured by the same accredited anthropometrist
using a standard protocol for the sum of 7 sites (triceps, biceps, subscapular, supraspinale, abdominal,
front thigh, medial calf; Holtain, Crymych, UK) at the start of each camp, and repeated mid-camp
(pre-TDF) and at the end of the camp (pre-TDU, pre-Volta, pre-TDF). Sleep quality was subjectively
rated each morning using a Likert scale (5 = very good; 4 = good; 3 = average; 2 = bad; 1 = very bad).
For camps at altitude, additional measures on waking included sleep hours (self-reported), resting
heart rate (HR) and peripheral oxygen saturation (SpO2) (CMS50H Pulse Oximeter, Contec Medical
Systems Co., Ltd., Qinhuangdao, China).
No athletes showed signs of underperformance, reduced wellness or illness, suggesting athletes
remained healthy and in a functional training state throughout each camp \[11\]. This may be
attributable to appropriate planning and day-to-day evaluation and adaptation of training prescription
at an individual level, hence prescribed group training loads are not reported here.

_2.3. Statistical Analysis_

Raw data and calculated daily/weekly intra-individual changes satisfied visual inspection and the
Shapiro–Wilk test for normality, with the exception of changes in body mass and skinfolds which were
slightly negatively skewed (SPSS version 24, IBM, Armonk, NY, USA). Normality was not improved by
transformation, hence raw body mass and skinfold data were used in analyses and mean and standard
deviation (SD) were deemed acceptable to describe the centrality and dispersion of data. The practical
importance of changes were calculated using magnitude based inferences \[12\].
The data were used to retrospectively evaluate the utility of commonly cited thresholds for daily
monitoring. The smallest worthwhile change (SWC) (0.3 _×_ SD/Mean _×_ 100) \[13\] and the smallest real
change (SRC) (1.96 _×_ _√_ 2 _×_ SD/ _\[√\]_ _n_, where n is the number of athletes from which the mean and SD

were derived) \[14\] were calculated from day 1 values, and applied to all subsequent days. The z-score
((value-Mean)/SD) was calculated on a daily basis, comparing the intra-individual change to the mean
group change for that day, with thresholds of 1.0 and 1.5 applied. The percentage of athletes ‘flagged’
by each criteria throughout each camp was calculated and averaged across camps.

**3. Results**

The measurements of cyclists and swimmers entering each training camp are detailed in Tables 1
and 2, respectively. Across all camps, athletes slept on average 8.0 _±_ 0.5 h on the first night, and rated
their sleep quality as 3.6 _±_ 0.8 out of 5 (average-good). Sleep was poorest for swimmers participating
in the Pre-Rio camp at altitude (7.5 _±_ 0.3 h, quality 2.3 _±_ 0.7 (bad)).
At altitude, the sleep quality of athletes very likely trivially improved week-to-week (mean
individual weekly change 0.3 _±_ 0.3 AU) (Figure 1A). Peripheral oxygen saturation possibly increased
week-to-week (0.6 _±_ 1.7%), whilst changes in resting HR were unclear (0 _±_ 4 bpm) (Figure 1B).

_Sports_ **2018**, _6_, 63 4 of 9

**Figure 1.** Change in sleep quality ( **A** ); resting heart rate and resting peripheral oxygen saturation
( **B** ) relative to Day 1 over the course of a training camp at altitude. Data presented as mean _±_ SD.
Symmetrical error bars above or below the mean values have been omitted for clarity.

The sum of 7 skinfolds most likely decreased during training camps, with an average reduction
of 3.1 _±_ 3.6 mm week-to-week (Figure 2). This was accompanied by a most likely trivial decrease in
body mass of 0.4 _±_ 0.4 kg week-to-week.

**Table 1.** Measurements of elite cyclists on day 1 of training camps, smallest worthwhile change
(SWC) and smallest real change (SRC) calculated from day 1, and mean changes observed during
~~training camps.~~

**Camp 1** **Camp 2** **Camp 3** **Camp 4**

**Camp Details**

Pre-TDU Early season Pre-Volta Pre-TDF
~~December 2012~~ ~~January 2013~~ ~~March 2013~~ ~~May 2013~~
Sea-level Sea-level Sea-level Altitude

~~Days~~ ~~9~~ ~~10~~ ~~10~~ ~~13~~
n 21 8 7 8

**Body mass (kg)** 68.8 _±_ 5.9 69.0 _±_ 6.7 64.5 _±_ 5.7 67.7 _±_ 6.1
SWC/SRC 2.6/3.5 2.9/6.5 2.7/6.0 2.7/6.0
Daily change 0.0 _±_ 0.1 _−_ 0.1 _±_ 0.1 _−_ 0.1 _±_ 0.1 _−_ 0.1 _±_ 0.1

**Skinfolds (sum 7 mm)** 41.8 _±_ 8.4 43.8 _±_ 7.1 38.2 _±_ 4.5 40.6 _±_ 3.9
SWC/SRC 6.0/5.1 4.8/6.9 3.5/4.7 2.9/3.8
~~Weekly change~~ ~~-~~ ~~_−_~~ ~~1.9~~ ~~_±_~~ ~~2.2~~ ~~-~~ ~~-~~

_Sports_ **2018**, _6_, 63 5 of 9

**Table 1.** _Cont_ .

**Camp 1** **Camp 2** **Camp 3** **Camp 4**

**Camp Details**

Pre-TDU Early season Pre-Volta Pre-TDF
December 2012 January 2013 March 2013 May 2013
Sea-level Sea-level Sea-level Altitude

**USG** 1.0194 _±_ 0.0066 1.0183 _±_ 0.0072 1.0154 _±_ 0.0076 1.0138 _±_ 0.0046

SWC/SRC 0.1954/0.0040 0.2110/0.0070 0.2250/0.0080 0.1371/0.0045
Daily change _−_ 0.0001 _±_ 0.0009 0.0002 _±_ 0.0011 0.0007 _±_ 0.0011 0.0003 _±_ 0.0006

**Resting HR (bpm)**  -  -  - 44 _±_ 8
SWC/SRC   -   -   - 6/8
Daily change   -   -   - 0.1 _±_ 0.3

**SpO2 (%)**   -   -   - 93.3 _±_ 1.3
SWC/SRC   -   -   - 0.4/1.3
Daily change   -   -   - 0.1 _±_ 0.2

**Sleep duration (h)**  -  -  - 8.4 _±_ 0.4
SWC/SRC   -   -   - 1.6/0.4
Daily change   -   -   - 0.0 _±_ 0.0

**Sleep quality (1–5)** 3.6 _±_ 0.5 4.0 _±_ 0.5 3.9 _±_ 0.4 3.8 _±_ 0.5
SWC/SRC 4.1/0.3 4.0/0.5 2.9/0.4 3.7/0.5
Daily change 0.0 _±_ 0.1 0.0 _±_ 0.0 0.0 _±_ 0.1 0.0 _±_ 0.1

Data presented as mean _±_ SD. TDU: Tour Down Under; Volta: Volta a Catalunya; TDF: Tour de France; USG:
Urinary specific gravity; HR: Heart rate; SpO2: Peripheral oxygen saturation.

**Table 2.** Measurements of elite swimmers on day 1 of training camps, smallest worthwhile change
(SWC) and smallest real change (SRC) calculated from day 1, and mean changes observed during
training camps.

**Camp 1** **Camp 2** **Camp 3** **Camp 4**

**Camp Details**

Early-season Pre-London Pre-Kazan Pre-Rio
January 2012 July 2012 June 2015 May 2016
Sea-level Altitude Altitude Altitude

Days 19 8 4 18
n 13 12 7 8

**Body mass (kg)** 65.0 _±_ 5.1 (F)    - 73.157.3 _± ±_ 7.3 (M) 7.5 (F) 77.255.4 _± ±_ 11.5 (M) 4.3 (F)
SWC/SRC 2.2/3.6    - 3.0/7.7 6.3/14.1
Daily change _−_ 0.1 _±_ 0.1     - _−_ 0.2 _±_ 0.1 _−_ 0.1 _±_ 0.1

57.1 _±_ 12.3 (F)
**Skinfolds (sum 7 mm)** 67.1 _±_ 9.9 (F) 79.4 _±_ 15.6 47.8 _±_ 5.4 (M)
66.1 _±_ 20.7 (M)

SWC/SRC 4.4/8.3 5.9/13.0 7.6/16.3 7.3/17.8
Weekly change    - _−_ 8.1 _±_ 4.1    - _−_ 2.0 _±_ 0.5

**USG** 1.0150 _±_ 0.0046 1.0215 _±_ 0.0054 1.0180 _±_ 0.0070 1.0172 _±_ 0.0060

SWC/SRC 0.1352/0.0035 0.1594/0.0043 0.2061/0.0073 0.1774/0.0059
Daily change     - _−_ 0.0003 _±_ 0.0013 _−_ 0.0005 _±_ 0.0020 0.0001 _±_ 0.0002

**Resting HR (bpm)**   - 54 _±_ 7 54 _±_ 7 53 _±_ 8
SWC/SRC    - 4/6 4/7 5/8
Daily change     - 0 _±_ 1 0 _±_ 2 0 _±_ 0

**SpO2 (%)**     - 95.3 _±_ 1.7 95.0 _±_ 1.6 94.0 _±_ 1.1
SWC/SRC    - 0.5/1.4 0.5/1.7 0.3/1.1
Daily change     - 0.2 _±_ 0.5 0.0 _±_ 0.5 0.1 _±_ 0.0

**Sleep duration (h)** 8.2 _±_ 0.2    -    - 7.5 _±_ 0.3
SWC/SRC 0.7/0.2    -    - 1.1/0.3
Daily change 0.0 _±_ 0.0     -     - 0.0 _±_ 0.0

**Sleep quality (1–5)** 3.7 _±_ 0.8   -   - 2.2 _±_ 0.7
SWC/SRC 6.3/0.6    -    - 9.4/0.7
Daily change 0.0 _±_ 0.1     -     - 0.1 _±_ 0.0

Data presented as mean _±_ SD. USG: Urinary specific gravity; HR: Heart rate; SpO2: Peripheral oxygen saturation.

_Sports_ **2018**, _6_, 63 6 of 9

When compared to the group values on day 1, 19 _±_ 25% of athletes exceeded the SWC threshold,
and 31 _±_ 21% of athletes exceeded the SRC threshold (Table 3). When compared to the daily change of
the group, 34 _±_ 3% and 16 _±_ 3% of athletes exceeded a z-score of 1.0 and 1.5 respectively.

**Table 3.** Percent of athletes flagged against the smallest worthwhile change (SWC) and smallest real
change (SRC) calculated from day 1, and z-scores calculated from the daily group change for each
measure for all training camps.

**Measure of Change** **SWC** **SRC** **z-Score 1.0** **z-Score 1.5**

Body mass 0 _±_ 0 0 _±_ 0 33 _±_ 5 17 _±_ 8
USG 0 _±_ 0 27 _±_ 18 35 _±_ 8 18 _±_ 7

Resting HR 32 _±_ 16 22 _±_ 16 32 _±_ 5 11 _±_ 8
SpO2 63 _±_ 8 25 _±_ 13 37 _±_ 4 16 _±_ 6
Sleep duration 20 _±_ 15 60 _±_ 10 30 _±_ 2 18 _±_ 7
Sleep qu ~~ality~~ ~~0~~ ~~_±_~~ ~~0~~ ~~49~~ ~~_±_~~ ~~11~~ ~~36~~ ~~_±_~~ ~~9~~ 19 _±_ 8

Data presented as mean _±_ SD. USG: Urinary specific gravity; HR: Heart rate; SpO2: Peripheral oxygen saturation.

**Figure 2.** Change in sum of 7 skinfold measurements relative to Day 1 over the course of a training
camp. Bold line is mean weekly change, summarizing illustrated individual responses for cyclists and
swimmers, males and females, training at sea-level or altitude.

**4. Discussion**

Training camp measurements of elite cyclists and swimmers have been retrospectively analysed
to offer insight into what is most often privileged information. Typical responses to training
camps included a shift in body composition and cardiovascular adaptation to altitude, whilst other
measurements remained stable.

_4.1. Change in Body Composition_

The primary physiological change observed in elite road cyclists and swimmers during training
camps was a decrease in body fat percentage as reflected by the sum of seven skinfolds. This was not
necessarily accompanied by a decrease in body mass. Reductions in body fat were likely intentional
and in line with individual performance goals (e.g., returning to ‘training weight’ at early season
camps, or achieving ‘race weight’ at pre-competition camps). Reduced fat mass is associated with
improved performance in swimmers \[15,16\] and cyclists who benefit from an increased power-to-weight
ratio \[10,17\].

_Sports_ **2018**, _6_, 63 7 of 9

_4.2. Changes Specific to Altitude_

A typical pattern of cardiovascular response to altitude hypoxia was observed \[18\], whereby
SpO2 was initially reduced and possibly normalized over the first week as the athletes adapted.
To accommodate the reduced SpO2, resting HR would have been higher than normal for these
athletes \[18\], however it was unclear whether HR decreased with time. This contrasts with the
response observed in elite distance runners who experienced a reduction in HR without a clear change
in SpO2 \[8\]. To more accurately ascertain the HR response, and differentiate between cardiovascular
adaptations to hypoxia, improvements in fitness, or possible training maladaptation, it is recommended
that athletes record their resting HR in the week prior to attending an altitude training camp.
An additional cardiovascular response to altitude hypoxia to consider is an increased blood
perfusion of skeletal muscles \[19\]. Increased perfusion of skeletal muscles has been associated with
increased muscle mass and decreased fat mass. This shift in body composition is consistent with the
observed reduction in skinfolds without a concomitant decrease in body mass. Energy balance may
also be shifted by reduced energy intake rather than an increased energy cost of training \[20\]. Athletes
should therefore tailor their energy and nutrient intakes to either exploit or counter these responses to
altitude, in line with their body composition goals.
The physiological stress of living at altitude is typically associated with dehydration (increased
USG) \[21\] and poor sleep quality \[22\]; however, these negative responses were not observed, except
for occasionally altered individual values. This likely reflects the elite athletes’ increased awareness
of hydration needs and also their experience in sleeping in different environments. It is possible
that sleep quality was overrated, as perceived adequate sleep duration (consistently ~8 h) may have
impaired athletes’ ability to appropriately determine their sleep quality \[23\]. Anecdotally, athletes
often report improved sleep with additional time spent at altitude, suggesting an adaptive response
to the altitude. Actigraphy may be useful to provide a more objective measurement of sleep quality
through an assessment of sleep efficiency.

_4.3. Informing Training Management_

Collectively, the observed physiological responses to training camps reflect the fitness and
experience of the elite cohort. Subjectively, the performance of athletes whilst training at the camps
and in subsequent major competitions, where applicable, suggested that the athletes responded
appropriately to a well-designed and managed training program, however we acknowledge this is
speculative without objective performance data during the camps. The routine monitoring of body
mass, skinfolds, sleep duration and quality, USG, resting HR, and SpO2 may have contributed to the
management of these athletes by providing additional insight to practitioners.
To facilitate the detection of possible maladaptation, practitioners may pre-set thresholds to
‘flag’ meaningful changes in measures. There is a need to balance the sensitivity and specificity of
thresholds, whereby it is feasible to follow up with the number of flagged athletes. In the training
camp scenario with limited numbers of athletes completing similar training, the z-score approach was
most successful to identify a small number of athletes each day whose response deviated from the
mean group response. Z-score thresholds of 1.0 and 1.5 remain arbitrary, and may be further refined
to suit the measure and/or training camp scenario. Nevertheless, thresholds are only intended to
assist the practitioner, and informal monitoring through conversations and observation of the athlete
remains a large component of athlete management.

_4.4. Practical Applications_

Practitioners seeking empirically supported guidance for elite athlete monitoring practices,
particularly during intense periods such as training camps, may draw upon the results, methods,
or overall learnings presented in this report. Firstly, the SWC and SRC values presented in Tables 1
and 2 may be used as thresholds for detecting meaningful change in similar cohorts and settings.

_Sports_ **2018**, _6_, 63 8 of 9

However, practitioners are also required to use their judgment in the instance that these calculated
values are non-sensical.

Practitioners working with different cohorts or settings, or where monitoring is already established,
may use the methods outlined here as a template to establish their thresholds. With sufficient data,
individual-specific parameters may also be determined. This approach may be further improved by
conducting repeat measurements to determine the reliability of measures \[24\].
Researchers agree that to-date, there is no single measure which can be used in isolation for
athlete monitoring \[2\]. Of greatest utility is subjective wellbeing, which may be supplemented by
other subjective and objective measures \[25\]. This includes measures to monitor the training response,
in addition to quantifying the internal and external loads. The challenge for practitioners is to weigh
the evidence for measures alongside the practical limitations of their particular setting (e.g., minimizing
burden for athletes and staff, cost of equipment).
In the present study, the utility of body composition, sleep, and USG for detecting possible signs
of maladaptation is unclear. However, it is worth considering their potential value for raising athlete
awareness and accountability of these factors which impact performance \[26\]. For instance, a perceived
reduction in sleep duration or quality may prompt an athlete to take a nap, or a higher USG reading
may prompt an athlete to drink more water. In these instances, understanding what is a meaningful
change may alleviate unnecessary obsessive behaviors.

**5. Conclusions**

Elite athletes experienced shifts in body composition during training camps, likely in line with
individual performance goals and possibly aided by altitude. The stability of other monitored measures
suggests athletes managed themselves appropriately, with the assistance of coaching and sport science
support. Comparing individual to group day-to-day change in monitored variables may prove effective
to flag athletes potentially at risk of training maladaptation. Practitioners may replicate these methods
to establish thresholds specific to their cohort and setting. This study provides further support for
a multi-faceted approach to monitoring elite athletes in training camp environments.

**Author Contributions:** Conceptualization, A.E.S., S.L.H., I.M.; Data curation, A.E.S., I.M.; Formal analysis, A.E.S.;
Investigation, I.M.; Methodology, I.M.; Project administration, I.M.; Writing—original draft, A.E.S., S.L.H., I.M.;
Writing—review & editing, A.E.S., S.L.H., I.M.

**Funding:** This research received no external funding

**Acknowledgments:** We thank the athletes, coaches, cycling team (Euskaltel Euskadi) and national swimming
federations (Fédération Française de Natation, Real Federación Española de Natación) for their cooperation with
monitoring practices and their consent to use and publish personal data.

**Conflicts of Interest:** The authors declare no conflict of interest.

**References**

1. Halson, S.L. Monitoring training load to understand fatigue in athletes. _Sports Med._ **2014**, _44_, 139–147.

[\[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1007/s40279-014-0253-z)

2. Meeusen, R.; Duclos, M.; Foster, C.; Fry, A.; Gleeson, M.; Nieman, D.; Raglin, J.; Rietjens, G.; Steinacker, J.;
   Urhausen, A. Prevention, diagnosis and treatment of the overtraining syndrome: Joint consensus statement
   of the European College of Sport Science (ECSS) and the American College of Sports Medicine (ACSM).
   _Eur. J. Sport Sci._ **2013**, _13_ [, 1–24. \[CrossRef\]](http://dx.doi.org/10.1080/17461391.2012.730061)
1. Bourdon, P.C.; Cardinale, M.; Murray, A.; Gastin, P.; Kellmann, M.; Varley, M.C.; Gabbett, T.J.; Coutts, A.J.;
   Burgess, D.J.; Gregson, W.; et al. Monitoring athlete training loads: Consensus statement. _Int. J. Sports_
   _Physiol. Perform._ **2017**, _12_ [, 161–170. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1123/IJSPP.2017-0208)
1. Halson, S.L.; Bridge, M.W.; Meeusen, R.; Busschaert, B.; Gleeson, M.; Jones, D.A.; Jeukendrup, A.E.
   Time course of performance changes and fatigue markers during intensified training in trained cyclists. _J._
   _Appl. Physiol._ **2002**, _93_ [, 947–956. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1152/japplphysiol.01164.2001)

_Sports_ **2018**, _6_, 63 9 of 9

5. Ten Haaf, T.; van Staveren, S.; Oudenhoven, E.; Piacentini, M.F.; Meeusen, R.; Roelands, B.; Koenderman, L.;

Daanen, H.A.; Foster, C.; de Koning, J.J. Prediction of functional overreaching from subjective fatigue and
readiness to train after only 3 days of cycling. _Int. J. Sports Physiol. Perform._ **2017**, _12_ [, 87–94. \[CrossRef\]](http://dx.doi.org/10.1123/ijspp.2016-0404)

[\[PubMed\]](http://www.ncbi.nlm.nih.gov/pubmed/27834554)

6. Chapman, R.F. The individual response to training and competition at altitude. _Br. J. Sports Med._ **2013**, _47_,
   [i40–i44. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1136/bjsports-2013-092837)

1. Passfield, L.; Hopker, J.G. A mine of information: Can sports analytics provide wisdom from your data?
   _Int. J. Sports Physiol. Perform._ **2017**, _12_ [, 851–855. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1123/ijspp.2016-0644)

1. Sperlich, B.; Achtzehn, S.; de Marées, M.; von Papen, H.; Mester, J. Load management in elite German
   distance runners during 3-weeks of high-altitude training. _Physiol. Rep._ **2016**, _4_ [, e12845. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.14814/phy2.12845)

1. Hopkins, W.G. Measures of reliability in sports medicine and science. _Sports Med._ **2000**, _30_ [, 1–15. \[CrossRef\]](http://dx.doi.org/10.2165/00007256-200030010-00001)

[\[PubMed\]](http://www.ncbi.nlm.nih.gov/pubmed/10907753)

10. Padilla, S.; Mujika, I.; Cuesta, G.; Goiriena, J.J. Level ground and uphill cycling ability in professional road
    cycling. _Med. Sci. Sports Exerc._ **1999**, _31_ [, 878–885. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1097/00005768-199906000-00017)
01. Halson, S.L.; Jeukendrup, A.E. Does overtraining exist? An analysis of overreaching and overtraining
    research. _Sports Med._ **2004**, _34_ [, 967–981. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.2165/00007256-200434140-00003)
01. Hopkins, W. A spreadsheet for deriving a confidence interval, mechanistic inference and clinical inference
    from a p value. _Sportscience_ **2007**, _11_, 16–20.
01. Hopkins, W.G.; Hawley, J.A.; Burke, L.M. Design and analysis of research on sport performance enhancement.
    _Med. Sci. Sports Exerc._ **1999**, _31_ [, 472–485. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1097/00005768-199903000-00018)
01. Beckerman, H.; Roebroeck, M.E.; Lankhorst, G.J.; Becher, J.G.; Bezemer, P.D.; Verbeek, A.L. Smallest real
    difference, a link between reproducibility and responsiveness. _Qual. Life Res._ **2001**, _10_ [, 571–578. \[CrossRef\]](http://dx.doi.org/10.1023/A:1013138911638)

[\[PubMed\]](http://www.ncbi.nlm.nih.gov/pubmed/11822790)

15. Anderson, M.E.; Hopkins, W.G.; Roberts, A.D.; Pyne, D.B. Monitoring seasonal and long-term changes in
    test performance in elite swimmers. _Eur. J. Sport Sci._ **2006**, _6_ [, 145–154. \[CrossRef\]](http://dx.doi.org/10.1080/17461390500529574)
01. Pyne, D.B.; Anderson, M.E.; Hopkins, W.G. Monitoring changes in lean mass of elite male and female
    swimmers. _Int. J. Sports Physiol. Perform._ **2006**, _1_ [, 14–26. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1123/ijspp.1.1.14)
01. Swain, D.P. The influence of body mass in endurance bicycling. _Med. Sci. Sports Exerc._ **1994**, _26_, 58–63.

[\[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1249/00005768-199401000-00011)

18. Mazzeo, R.S. Physiological responses to exercise at altitude. _Sports Med._ **2008**, _38_ [, 1–8. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.2165/00007256-200838010-00001)
01. Chia, M.; Liao, C.A.; Huang, C.Y.; Lee, W.C.; Hou, C.W.; Yu, S.H.; Harris, M.B.; Hsu, T.S.; Lee, S.D.; Kuo, C.H.
    Reducing body fat with altitude hypoxia training in swimmers: Role of blood perfusion to skeletal muscles.
    _Chin. J. Physiol._ **2013**, _56_ [, 18–25. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.4077/CJP.2013.BAA071)
01. Westerterp, K.R.; Kayser, B. Body mass regulation at altitude. _Eur. J. Gastroenterol. Hepatol._ **2006**, _18_, 1–3.

[\[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1097/00042737-200601000-00001)

21. Sawka, M.N.; Cheuvront, S.N.; Kenefick, R.W. Hypohydration and human performance: Impact of
    environment and physiological mechanisms. _Sports Med._ **2015**, _45_ [, 51–60. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1007/s40279-015-0395-7)
01. Weil, J.V. Sleep at high altitude. _High Alt. Med. Biol._ **2004**, _5_ [, 180–189. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1089/1527029041352162)
01. Lalor, B.J.; Halson, S.L.; Tran, J.; Kemp, J.G.; Cormack, S.J. Competition sleep is not compromised compared
    to habitual in elite Australian footballers. _Int. J. Sports Physiol. Perform._ **2017**, _13_, 1–23.
01. Crowcroft, S.; McCleave, E.; Slattery, K.; Coutts, A.J. Assessing the measurement sensitivity and diagnostic
    characteristics of athlete-monitoring tools in national swimmers. _Int. J. Sports Physiol. Perform._ **2017**, _12_, 95–100.

[\[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1123/ijspp.2016-0406)

25. Saw, A.E.; Main, L.C.; Gastin, P.B. Monitoring the athlete training response: Subjective self-reported measures
    trump commonly used objective measures: A systematic review. _Br. J. Sports Med._ **2016**, _50_, 281–291.

[\[CrossRef\] \[PubMed\]](http://dx.doi.org/10.1136/bjsports-2015-094758)

26. Saw, A.; Main, L.; Robertson, S.; Gastin, P. Athlete self-report measure use and associated psychological
    alterations. _Sports_ **2017**, _5_ [, 54. \[CrossRef\] \[PubMed\]](http://dx.doi.org/10.3390/sports5030054)

© 2018 by the authors. Licensee MDPI, Basel, Switzerland. This article is an open access

article distributed under the terms and conditions of the Creative Commons Attribution

[(CC BY) license (http://creativecommons.org/licenses/by/4.0/).](http://creativecommons.org/licenses/by/4.0/.)
